
Distance weighted discrimination (DWD) linear classifier.

Another Look at DWD: Thrifty Algorithm
and Bayes Risk Consistency in RKHS
(https://arxiv.org/pdf/1508.05913.pdf, https://rss.onlinelibrary.wiley.com/doi/pdf/10.1111/rssb.12244?casa_token=kVUIK7AbaaAAAAAA:Y1EAXkLOND3vAjYHvFH15qm43binUJJ1ECFXJXxxCU1Wd_kbY37FtyiStpFpGmpLOAXL28gECx6bDGje)

Fast algorithms for large scale generalized
distance weighted discrimination
(https://arxiv.org/pdf/1604.05473.pdf)

Weighted Distance Weighted Discrimination and
Its Asymptotic Properties
(https://www.tandfonline.com/doi/pdf/10.1198/jasa.2010.tm08487?casa_token=AZOStahgPrIAAAAA:aqJP3bDI-i0O9blEaHtRt5erGk4dJ_aVyC0VywPcAZu-81HrcRboYJEwIX53bkbLzbCk9sqlKA_LRA)

Distance-Weighted Discrimination
(https://www.tandfonline.com/doi/pdf/10.1198/016214507000001120?casa_token=ycIqVLUAMoQAAAAA:eXmC8WczVyxbSSMwV9jjVoBvEzvNIHmy-3x8EX3Y9UIpZLm_1GEmagfB5ajFRvsRmGBLow_CRQXIzg)
